ggf documentation
=================

ggf is a Python library for computing global geometric factors and
corresponding stresses acting on dielectric objects in the
optical stretcher.

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   installation
   sec_introduction
   sec_theory_notes
   sec_examples
   sec_code_reference
   sec_changelog
   z_bib


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
